TEST_IMPORT_SETUP_LABEL = 'test import setup'
TEST_IMPORT_SETUP_LABEL_EDITED = 'test import setup edited'
TEST_IMPORT_SETUP_PROCESS_SIZE = 1
TEST_IMPORTER_BACKEND_PATH = 'importer.tests.test_importers.TestImporter'
